<?php
namespace FiloBlu\DisableShop\Controller\Index;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem;
use Magento\Framework\App\Request\DataPersistorInterface;

class ProductInfo extends Action
{
    private $dataPersistor;
    /**
     * @return \Magento\Framework\Controller\Result\Redirect|\Magento\Framework\View\Result\Page
     */

    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        Filesystem $fileSystem,
        \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder,
        \Magento\Store\Model\StoreManagerInterface $_storeManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
    )
    {
        parent::__construct($context);
        $this->fileSystem = $fileSystem;
        $this->_transportBuilder = $transportBuilder;
        $this->_storeManager = $_storeManager;
        $this->_scopeConfig = $scopeConfig;
        $this->_resultJsonFactory = $resultJsonFactory;
    }

    public function execute()
    {

        $resultJson = $this->_resultJsonFactory->create();
        $post = $this->getRequest()->getPostValue();


        $recipientEmail = $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_email',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

        $askInfoEmailTemplate = $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_email_template',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

        $askInfoEmailTemplateToCustomer = $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_email_template_to_customer',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

        // Email sender to store
        $fromEmailToStore = $post['info_email'];

        $templateVarsToStore = [
            'store' => $this->_storeManager->getStore(),
            'customer_email' => $post['info_email'],
            'product_name' => $post['info_product_name'],
            'product_sku' => $post['info_sku'],
        ];

        $fromToStore = ['email' => $fromEmailToStore, 'name' => ''];
        $toToStore = $recipientEmail;


        $templateOptions = [
            'area' => \Magento\Framework\App\Area::AREA_FRONTEND,
            'store' => \Magento\Store\Model\Store::DEFAULT_STORE_ID
        ];

        try {
                $transport = $this->_transportBuilder->setTemplateIdentifier($askInfoEmailTemplate)
                    ->setTemplateOptions($templateOptions)
                    ->setTemplateVars($templateVarsToStore)
                    ->setFrom($fromToStore)
                    ->addTo($toToStore)
                    ->getTransport();
            $transport->sendMessage();

        } catch (\Magento\Framework\Exception\LocalizedException $e) {
            return $resultJson->setData(['success' => false, 'error' => true, 'message' => __('There was a problem with the request: %1', $e->getMessage())]);
        } catch (\Exception $e) {
            return $resultJson->setData(['success' => false, 'error' => true, 'message' => __($e->getMessage())]);
        }

        //Email sender to customer
        $templateVarsToCustomer = [
            'store' => $this->_storeManager->getStore(),
            'product_name' => $post['info_product_name']
        ];

        $fromEmailToCustomer = $recipientEmail;
        $fromToCustomer = ['email' => $fromEmailToCustomer, 'name' => ''];

        $toToCustomer = $post['info_email'];

        try {
            $transport = $this->_transportBuilder->setTemplateIdentifier($askInfoEmailTemplateToCustomer)
                ->setTemplateOptions($templateOptions)
                ->setTemplateVars($templateVarsToCustomer)
                ->setFrom($fromToCustomer)
                ->addTo($toToCustomer)
                ->getTransport();
            $transport->sendMessage();

        }
        catch (\Exception $e) {
            return $resultJson->setData(['success' => false, 'error' => true, 'message' => __($e->getMessage())]);
        }

        $resultJson->setData(['success' => true, 'error' => false, 'message' => __('Apointment request recived, a recap email has been sent to you')]);

        return $resultJson;
    }
}